# coding=utf-8
# Action summary dialog
#
# Copyright (C) 2013  Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# the GNU General Public License v.2, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY expressed or implied, including the implied warranties of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the
# GNU General Public License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
# source code or documentation are not subject to the GNU General Public
# License and may only be used or replicated with the express permission of
# Red Hat, Inc.
#
# Red Hat Author(s): Chris Lumens <clumens@redhat.com>
#

from pyanaconda.ui.gui import GUIObject
from pyanaconda.ui.gui.utils import escape_markup

from blivet.deviceaction import ACTION_TYPE_DESTROY, ACTION_TYPE_RESIZE, ACTION_OBJECT_FORMAT

__all__ = ["ActionSummaryDialog","AutopartSummaryDialog","KeepUserDataSummaryDialog"]

class ActionSummaryDialog(GUIObject):
    builderObjects = ["actionStore", "summaryDialog"]
    mainWidgetName = "summaryDialog"
    uiFile = "spokes/lib/summary.glade"

    def __init__(self, data):
        GUIObject.__init__(self, data)
        self._store = self.builder.get_object("actionStore")

    # pylint: disable=arguments-differ
    def initialize(self, actions):
        for (i, action) in enumerate(actions, start=1):
            mountpoint = ""

            if action.type in [ACTION_TYPE_DESTROY, ACTION_TYPE_RESIZE]:
                typeString = """<span foreground='red'>%s</span>""" % \
                        escape_markup(action.typeDesc.title())
            else:
                typeString = """<span foreground='green'>%s</span>""" % \
                        escape_markup(action.typeDesc.title())
                if action.obj == ACTION_OBJECT_FORMAT:
                    mountpoint = getattr(action.device.format, "mountpoint", "")

            self._store.append([i,
                                typeString,
                                action.objectTypeString,
                                action.device.name,
                                mountpoint])

    # pylint: disable=arguments-differ
    def refresh(self, actions):
        GUIObject.refresh(self)

        self._store.clear()
        self.initialize(actions)

    def run(self):
        rc = self.window.run()
        self.window.destroy()
        return rc
class AutopartSummaryDialog(GUIObject):
    builderObjects = ["autopart_dialog"]
    mainWidgetName = "autopart_dialog"
    uiFile = "spokes/lib/summary.glade"

    def __init__(self):
        GUIObject.__init__(self,None)
	self._warn_label = self.builder.get_object("label3")
	self._ok_button = self.builder.get_object("ok_button")
	self._cancel_button = self.builder.get_object("cancel_button")
	
	self._warn_label.set_text("此磁盘上所有的数据将被清空!\n")
	self._ok_button.set_label("确认")
	self._cancel_button.set_label("取消")

    # pylint: disable=arguments-differ
    def initialize(self):
	print "initialize AutopartSummaryDialog"
    # pylint: disable=arguments-differ
    def refresh(self):
        #GUIObject.refresh()

        self.initialize()

    def run(self):
        rc = self.window.run()
        self.window.destroy()
        return rc
class KeepUserDataSummaryDialog(GUIObject):
    builderObjects = ["autopart_keepdata_dialog"]
    mainWidgetName = "autopart_keepdata_dialog"
    uiFile = "spokes/lib/summary.glade"

    def __init__(self):
        GUIObject.__init__(self,None)
	self._warn_label = self.builder.get_object("label4")
	self._ok_button = self.builder.get_object("ok_button1")
	self._cancel_button = self.builder.get_object("cancel_button1")
	self._clean_all = self.builder.get_object("clean_all")
	self._keep_data = self.builder.get_object("keep_data")
	
	self._warn_label.set_text("请选择安装方式：\n")
	self._ok_button.set_label("确认")
	self._cancel_button.set_label("取消")
	self._clean_all.set_label("全盘安装")
	self._keep_data.set_label("全盘安装(保留用户数据)")
    # pylint: disable=arguments-differ
    def initialize(self):
	print "initialize AutopartSummaryDialog"
	import os
	keep_flags = os.system("grep KEEP_HOME=YES /tmp/keephome.txt 2>/dev/null")
	if  keep_flags == 0:
	    print "KEEP_HOME=YES"
	else:
	    print "KEEP_HOME=NO"
	    self._keep_data.set_sensitive(False)
    def refresh(self):
        #GUIObject.refresh()
        self.initialize()

    def on_keepdata_toggled(self,widget):
	import os
	if self._clean_all.get_active():
	    print "select self._clean_all"
	    os.system("rm -rf /tmp/.KEEP_HOME_YES")
	else:
	    print "select keep_data"
	    os.system("touch /tmp/.KEEP_HOME_YES")

    def run(self):
        rc = self.window.run()
        self.window.destroy()
        return rc
